@@ -45,14 +45,12 @@ class User:
     """Fetch user albums."""
     logger.log(5, 'Fetching user albums...')
     n = 1
-    raw_data = []
     while True:
       logger.info(f'Fetching user albums page: {n}...')
       response = requests.post('https://members.luscious.net/graphql/nobatch/?operationName=AlbumList',
                                json=user_albums_query(str(self.id_), n)).json()
-      raw_data.extend(response['data']['album']['list']['items'])
+      self.albums_ids.extend([album['id'] for album in response['data']['album']['list']['items']])
       n += 1
       if not response['data']['album']['list']['info']['has_next_page']:
         break
-    self.albums_ids = [album['id'] for album in raw_data]
     logger.info(f'Total of {len(self.albums_ids)} ids found.')
